# acoustics-toolbox
Ce package contient les modules suivant :
- acoustics_basics : manipulation des niveaux sonores, des pondérations acoustiques, et des bandes de fréquence
- outdoor_propagtion_tools : conversions de vitesses de vent et de résistance au passage de l'air, calcul de distance source-récepteur, et autres...
- replicate_iso9613_1 : méthode de calcul de l'absorption atmosphérique du son selon la norme ISO9613-1
- replicate_iso9613_1 : méthode de calcul de la propagation du son en extérieur selon la norme ISO9613-2